#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-gadt-plugin-2.3.0.0-BjC11GT0o2GH9Tat5EfgN2
key:                  hls-gadt-plugin-2.3.0.0-BjC11GT0o2GH9Tat5EfgN2
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  aa2de40bb7cf748449ce5574d84f5c6e
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.3.0.0-BjC11GT0o2GH9Tat5EfgN2
depends:
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0 base-4.18.2.1 containers-0.6.7
    extra-1.7.16-9HJWsKGqeQNGNK4b68nPpp ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-8hKu1Ja81dnAmH9M3NOlwh
    ghcide-2.3.0.0-Bfg1eWqKv2P9EhjAubTTO0
    hls-plugin-api-2.3.0.0-2cVMP2AJp9EB89sXuyaAt3
    hls-refactor-plugin-2.3.0.0-G8XojnaKoxvI5XCS3WShcB
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

